@@ -2,8 +2,9 @@ from . import resources
 from .custom_server import custom_server
 from .deployment import deployment
 from .tokens import token_util
+from .simple_jwt import simple_jwt
 from importlib_metadata import version
 
-__all__ = ["resources", "custom_server", "deployment", "token_util"]
+__all__ = ["resources", "custom_server", "deployment", "token_util", "simple_jwt"]
 
 __version__ = version("willing_zg")
